Task

Struct Task 

pub struct Task {
    pub origin_id: u32,
    pub nprobes: u32,
    pub session_id: u32,
    pub task_type: Option<TaskType>,
}
A task (i.e., measurement) for a worker to perform, either a probe, traceroute, or discovery task

Fields

origin_id: u32

Origin from which to send this probe

nprobes: u32

number of times the worker sends this probe, spaced by the Start probe_interval

session_id: u32

16-bit session ID encoded in the probe; ICMP/DNS-A only

task_type: Option<TaskType>